# Django MarkdownX

Django MarkdownX is a comprehensive [Markdown](https://en.wikipedia.org/wiki/Markdown) plugin built for [Django](https://www.djangoproject.com), the renowned high-level Python web framework, with flexibility, extensibility, and ease-of-use at its core.

**GitHub:** [https://github.com/neutronX/django-markdownx](https://github.com/neutronX/django-markdownx)<br>
**PyPi:** [https://pypi.org/project/django-markdownx/](https://pypi.org/project/django-markdownx/)

## Key features

* Raw editing.
* Live preview.
* Drag & drop image uploads (automatically stored in the designated location in the *Media* directory).
* Customizable image insertion tag.
* Definition of maximum size for an image.
* Definition of acceptable image formats (PNG, JPEG, SVG).
* Image manipulations (compression, size reduction, cropping, upscaling).
* Pre- and post- text modification.
* Easy template customization, layout modification, and personalization.
* Multiple editors per page.
* Django Admin support.

## Preview

![django-markdownx preview](https://github.com/neutronX/django-markdownx/raw/master/django-markdownx-preview.gif?raw=true)
